%define anolis_release 1

Name:           openssl-pkcs11
Version:        0.4.12
Release:        %{anolis_release}%{?dist}
Summary:        A PKCS#11 engine for use with OpenSSL
# The source code is LGPLv2+ except eng_back.c and eng_parse.c which are BSD
License:        LGPLv2+ and BSD
URL:            https://github.com/OpenSC/libp11
Source0:        https://github.com/OpenSC/libp11/releases/download/libp11-%{version}/libp11-%{version}.tar.gz

# Downstream only for now to make RSA operations working in FIPS mode
Patch4:         openssl-pkcs11-0.4.10-set-rsa-fips-method-flag.patch
# unbreak operation when some other engine is present in openssl.cnf
# https://github.com/OpenSC/libp11/pull/460
# https://github.com/OpenSC/libp11/commit/feb22a66
Patch5:         openssl-pkcs11-ossl3.patch

BuildRequires:  make
BuildRequires:  autoconf automake libtool
BuildRequires:  pkgconfig(libcrypto) >= 0.9.8
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(p11-kit-1)
# Needed for testsuite
BuildRequires:  softhsm opensc procps-ng
BuildRequires:  openssl


Requires:       p11-kit-trust

# Package renamed from libp11 to openssl-pkcs11 in release 0.4.7-4
Provides:       libp11 = %{version}-%{release}
Obsoletes:      libp11 < 0.4.7-4
# The engine_pkcs11 subpackage is also provided 
Provides:       engine_pkcs11 = %{version}-%{release}
Obsoletes:      engine_pkcs11 < 0.4.7-4


%description -n openssl-pkcs11
openssl-pkcs11 enables hardware security module (HSM), and smart card support in
OpenSSL applications. More precisely, it is an OpenSSL engine which makes
registered PKCS#11 modules available for OpenSSL applications. The engine is
optional and can be loaded by configuration file, command line or through the
OpenSSL ENGINE API.


%prep
%autosetup -p1 -n libp11-%{version}

%build
%configure --disable-static
%make_build

%install
%make_install

## Remove development files
rm -f %{buildroot}%{_libdir}/libp11.so
rm -f %{buildroot}%{_libdir}/pkgconfig/libp11.pc
rm -f %{buildroot}%{_includedir}/*.h

# Remove documentation automatically installed by make install
rm -rf %{buildroot}%{_docdir}

%check
%make_build check || if [ $? -ne 0 ]; then cat tests/*.log; exit 1; fi;

%files
%license COPYING
%doc NEWS
%{_libdir}/libp11.so.*
%{_libdir}/engines-*/*.so

%changelog
* Mon Jan 30 2023 Funda Wang <fundawang@yeah.net> - 0.4.12-1
- New version 0.4.12

* Mon Mar 14 2022 Renbo <rb01097748@alibaba-inc.com> - 0.4.11-1
- Init for Anolis OS 23
